"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useSelectInputProps_1 = tslib_1.__importDefault(require("./useSelectInputProps"));
const useCoverQuestionProps_1 = tslib_1.__importDefault(require("./useCoverQuestionProps"));
const useOpenTextInputProps_1 = tslib_1.__importDefault(require("./useOpenTextInputProps"));
const useNextQuestionButtonProps_1 = tslib_1.__importDefault(require("./useNextQuestionButtonProps"));
const usePreviousQuestionButtonProps_1 = tslib_1.__importDefault(require("./usePreviousQuestionButtonProps"));
const useAddToFavoritesButtonProps_1 = tslib_1.__importDefault(require("./useAddToFavoritesButtonProps"));
const useSkipQuestionButtonProps_1 = tslib_1.__importDefault(require("./useSkipQuestionButtonProps"));
const usePropsGetters = (quizEvents, quizApiState, quizLocalState, favoriteItems) => {
    var _a, _b, _c;
    const { quizAnswerChanged, nextQuestion, skipQuestion, previousQuestion, resetQuiz, hydrateQuiz, addToCart, addToFavorites, resultClick, } = quizEvents;
    const getOpenTextInputProps = (0, useOpenTextInputProps_1.default)(quizAnswerChanged, nextQuestion, (_a = quizApiState.quizCurrentQuestion) === null || _a === void 0 ? void 0 : _a.next_question, quizLocalState.answerInputs);
    const getCoverQuestionProps = (0, useCoverQuestionProps_1.default)(quizAnswerChanged, (_b = quizApiState.quizCurrentQuestion) === null || _b === void 0 ? void 0 : _b.next_question);
    const getSelectInputProps = (0, useSelectInputProps_1.default)(quizAnswerChanged, nextQuestion, (_c = quizApiState.quizCurrentQuestion) === null || _c === void 0 ? void 0 : _c.next_question, quizLocalState.answerInputs);
    const getNextQuestionButtonProps = (0, useNextQuestionButtonProps_1.default)(nextQuestion, quizApiState, quizLocalState);
    const getSkipQuestionButtonProps = (0, useSkipQuestionButtonProps_1.default)(skipQuestion, quizApiState);
    const getPreviousQuestionButtonProps = (0, usePreviousQuestionButtonProps_1.default)(quizApiState, previousQuestion);
    const getResetQuizButtonProps = (0, react_1.useCallback)((stylesType = 'primary') => ({
        className: stylesType === 'primary' ? 'cio-question-cta-button' : 'cio-question-redo-button',
        type: 'button',
        onClick: () => resetQuiz(),
    }), [resetQuiz]);
    const getHydrateQuizButtonProps = (0, react_1.useCallback)(() => ({
        className: '',
        type: 'button',
        onClick: () => hydrateQuiz(),
    }), [hydrateQuiz]);
    const getAddToCartButtonProps = (0, react_1.useCallback)((result, price) => ({
        className: 'cio-result-card-cta-button',
        type: 'button',
        onClick: (e) => addToCart(e, result, price),
    }), [addToCart]);
    const getAddToFavoritesButtonProps = (0, useAddToFavoritesButtonProps_1.default)(addToFavorites, favoriteItems);
    const quizResultClickDown = (0, react_1.useCallback)((event, result, position) => {
        if ((event === null || event === void 0 ? void 0 : event.key) === ' ' || (event === null || event === void 0 ? void 0 : event.key) === 'Enter') {
            if (resultClick) {
                resultClick(result, position);
            }
        }
    }, [resultClick]);
    const getQuizResultButtonProps = (0, react_1.useCallback)(({ result, position }) => ({
        className: 'cio-result-card-container',
        role: 'button',
        tabIndex: 0,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizResultLinkProps = (0, react_1.useCallback)(({ result, position }) => {
        var _a;
        return ({
            href: (_a = result.data) === null || _a === void 0 ? void 0 : _a.url,
            onClick: () => resultClick(result, position),
            onKeyDown: (event) => quizResultClickDown(event, result, position),
        });
    }, [quizResultClickDown, resultClick]);
    const getQuizImageProps = (0, react_1.useCallback)(() => {
        var _a, _b, _c, _d, _e, _f;
        return ({
            src: ((_c = (_b = (_a = quizApiState.quizCurrentQuestion) === null || _a === void 0 ? void 0 : _a.next_question) === null || _b === void 0 ? void 0 : _b.images) === null || _c === void 0 ? void 0 : _c.primary_url) || undefined,
            alt: ((_f = (_e = (_d = quizApiState.quizCurrentQuestion) === null || _d === void 0 ? void 0 : _d.next_question) === null || _e === void 0 ? void 0 : _e.images) === null || _f === void 0 ? void 0 : _f.primary_alt) || undefined,
        });
    }, [quizApiState.quizCurrentQuestion]);
    const getSelectQuestionImageProps = (0, react_1.useCallback)((option) => {
        var _a, _b;
        return ({
            className: 'cio-question-option-image',
            src: ((_a = option === null || option === void 0 ? void 0 : option.images) === null || _a === void 0 ? void 0 : _a.primary_url) || undefined,
            alt: ((_b = option === null || option === void 0 ? void 0 : option.images) === null || _b === void 0 ? void 0 : _b.primary_alt) || undefined,
        });
    }, []);
    return {
        getOpenTextInputProps,
        getNextQuestionButtonProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getSelectQuestionImageProps,
        getSelectInputProps,
        getCoverQuestionProps,
        getResetQuizButtonProps,
        getHydrateQuizButtonProps,
        getAddToCartButtonProps,
        getAddToFavoritesButtonProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
        getSkipQuestionButtonProps,
    };
};
exports.default = usePropsGetters;
