"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const actions_1 = require("../../components/CioQuiz/actions");
const quizApiReducer_1 = tslib_1.__importStar(require("../../components/CioQuiz/quizApiReducer"));
const services_1 = require("../../services");
const useQuizApiState = (quizOptions, cioClient, quizLocalState, skipToResults, dispatchLocalState
// eslint-disable-next-line max-params
) => {
    const [quizApiState, dispatchApiState] = (0, react_1.useReducer)(quizApiReducer_1.default, quizApiReducer_1.initialState);
    const { quizId, quizVersionId: quizVersionIdProp, resultsPageOptions } = quizOptions;
    const dispatchQuizResults = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        try {
            const quizResults = yield (0, services_1.getQuizResults)(cioClient, quizId, {
                answers: quizLocalState.answers,
                resultsPerPage: resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.numResultsToDisplay,
                quizVersionId: quizLocalState.quizVersionId,
                quizSessionId: quizLocalState.quizSessionId,
            });
            // Set quiz results state
            dispatchApiState({
                type: actions_1.QuizAPIActionTypes.SET_QUIZ_RESULTS,
                payload: {
                    quizResults,
                },
            });
            if (!quizLocalState.isQuizCompleted)
                dispatchLocalState({
                    type: actions_1.QuestionTypes.Complete,
                });
        }
        catch (error) {
            dispatchApiState({
                type: actions_1.QuizAPIActionTypes.SET_IS_ERROR,
            });
        }
    });
    (0, react_1.useEffect)(() => {
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            dispatchApiState({
                type: actions_1.QuizAPIActionTypes.SET_IS_LOADING,
            });
            if (quizLocalState.isLastAnswer || skipToResults) {
                yield dispatchQuizResults();
            }
            else {
                try {
                    const quizVersionId = quizLocalState.quizVersionId || quizVersionIdProp;
                    const { quizSessionId } = quizLocalState;
                    const questionResult = yield (0, services_1.getNextQuestion)(cioClient, quizId, {
                        answers: quizLocalState.answers,
                        quizVersionId,
                        quizSessionId,
                    });
                    if (!questionResult.next_question) {
                        yield dispatchQuizResults();
                        return;
                    }
                    // Update quizSessionId, quizVersionId
                    if ((!quizSessionId && (questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_session_id)) ||
                        (!quizVersionId && questionResult.quiz_version_id)) {
                        dispatchLocalState({
                            type: actions_1.QuestionTypes.Hydrate,
                            payload: {
                                quizVersionId: questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_version_id,
                                quizSessionId: questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_session_id,
                            },
                        });
                    }
                    // Set current question state
                    dispatchApiState({
                        type: actions_1.QuizAPIActionTypes.SET_CURRENT_QUESTION,
                        payload: {
                            quizCurrentQuestion: questionResult,
                        },
                    });
                }
                catch (error) {
                    dispatchApiState({
                        type: actions_1.QuizAPIActionTypes.SET_IS_ERROR,
                    });
                }
            }
        }))();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [cioClient, quizId, quizLocalState.answers, resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.numResultsToDisplay]);
    return {
        quizApiState,
        dispatchApiState,
    };
};
exports.default = useQuizApiState;
